==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SelectedItemsChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescriptionMetadata } from "./SelectedItemsChangedEventArgsDescriptionMetadata";
import { SelectedItemsChangingEventArgsDescription } from "./SelectedItemsChangingEventArgsDescription";
/**
 * @hidden
 */
export let SelectedItemsChangingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedItemsChangingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedItemsChangingEventArgsDescriptionMetadata.a == null) {
                SelectedItemsChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedItemsChangingEventArgsDescriptionMetadata.c(SelectedItemsChangingEventArgsDescriptionMetadata.a);
            }
            if (a.j(SelectedItemsChangingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SelectedItemsChangingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            SelectedItemsChangedEventArgsDescriptionMetadata.c(a);
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            SelectedItemsChangingEventArgsDescriptionMetadata.b(a);
            a.aa("SelectedItemsChangingEventArgs", () => new SelectedItemsChangingEventArgsDescription());
            a.z("SelectedItemsChangingEventArgs", SelectedItemsChangingEventArgsDescriptionMetadata.a);
        }
    }
    SelectedItemsChangingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectedItemsChangingEventArgsDescriptionMetadata, 'SelectedItemsChangingEventArgsDescriptionMetadata');
    SelectedItemsChangingEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SelectedItemsChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescriptionMetadata } from "./SelectedItemsChangedEventArgsDescriptionMetadata";
import { SelectedItemsChangingEventArgsDescription } from "./SelectedItemsChangingEventArgsDescription";
/**
 * @hidden
 */
export let SelectedItemsChangingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedItemsChangingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedItemsChangingEventArgsDescriptionMetadata.a == null) {
                SelectedItemsChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedItemsChangingEventArgsDescriptionMetadata.c(SelectedItemsChangingEventArgsDescriptionMetadata.a);
            }
            if (a.k(SelectedItemsChangingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SelectedItemsChangingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            SelectedItemsChangedEventArgsDescriptionMetadata.c(a);
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            SelectedItemsChangingEventArgsDescriptionMetadata.b(a);
            a.ac("SelectedItemsChangingEventArgs", () => new SelectedItemsChangingEventArgsDescription());
            a.ab("SelectedItemsChangingEventArgs", SelectedItemsChangingEventArgsDescriptionMetadata.a);
        }
    }
    SelectedItemsChangingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectedItemsChangingEventArgsDescriptionMetadata, 'SelectedItemsChangingEventArgsDescriptionMetadata');
    SelectedItemsChangingEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangingEventArgsDescriptionMetadata;
})();
